<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="ru_RU">
<defaultcodec></defaultcodec>
<context>
    <name>QStarDict::CSSEdit</name>
    <message>
        <location filename="../cssedit.ui" line="16"/>
        <source>Preview</source>
        <translation>Предварительный просмотр</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="30"/>
        <source>Element</source>
        <translation>Элемент</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="37"/>
        <source>Foreground</source>
        <translation>Цвет шрифта</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="44"/>
        <source>Background</source>
        <translation>Цвет фона</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="51"/>
        <source>Select element</source>
        <translation>Выберите элемент</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="68"/>
        <source>Click to select color</source>
        <translation>Нажмите чтобы выбрать элемент</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="71"/>
        <source>#000000</source>
        <translation>#000000</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="78"/>
        <source>Font</source>
        <translation>Шрифт</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="85"/>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="92"/>
        <source>Select font</source>
        <translation>Выберите шрифт</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="99"/>
        <source>Select font size</source>
        <translation>Выберите размер шрифта</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="102"/>
        <source>pt</source>
        <translation>пт</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="127"/>
        <source>Bold</source>
        <translation>Жирный</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="130"/>
        <source>B</source>
        <translation>Ж</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="147"/>
        <source>Italic</source>
        <translation>Курсив</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="150"/>
        <source>I</source>
        <translation>К</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="167"/>
        <source>Underline</source>
        <translation>Подчеркнутый</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="170"/>
        <source>U</source>
        <translation>П</translation>
    </message>
</context>
<context>
    <name>QStarDict::DictBrowser</name>
    <message>
        <location filename="../dictbrowser.cpp" line="72"/>
        <source>The word &lt;b&gt;%1&lt;/b&gt; is not found.</source>
        <translation>Слово &lt;b&gt;%1&lt;/b&gt; не найдено.</translation>
    </message>
</context>
<context>
    <name>QStarDict::DictWidget</name>
    <message>
        <location filename="../dictwidget.cpp" line="114"/>
        <source>Save translation</source>
        <translation>Сохранить перевод</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="135"/>
        <source>HTML files (*.html, *.htm)</source>
        <translation>HTML-файлы (*.html, *.htm)</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="124"/>
        <source>Text files (*.txt)</source>
        <translation>Текстовые файлы (*.txt)</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="130"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="131"/>
        <source>Cannot save translation as %1</source>
        <translation>Невозможно сохранить перевод как %1</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="75"/>
        <source>Go to &amp;previous translation</source>
        <translation>Перейти к &amp;предыдущему переводу</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="80"/>
        <source>Go to &amp;next translation</source>
        <translation>Перейти к &amp;следующему переводу</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="85"/>
        <source>&amp;Save to file</source>
        <translation>&amp;Сохранить в файл</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="91"/>
        <source>Speak &amp;word</source>
        <translation>П&amp;роизнести слово</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="88"/>
        <source>Prin&amp;t translation</source>
        <translation>Напечата&amp;ть перевод</translation>
    </message>
</context>
<context>
    <name>QStarDict::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="114"/>
        <source>About QStarDict</source>
        <translation>О программе QStarDict</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="115"/>
        <source>&lt;b&gt;QStarDict %1 &lt;/b&gt; - Qt version of StarDict&lt;br&gt;</source>
        <translation>&lt;b&gt;QStarDict %1 &lt;/b&gt; - Qt-версия программы StarDict&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="117"/>
        <source>Copyright (C) 2007 Alexander Rodin &lt;a href=&quot;http://qstardict.ylsoftware.com&quot;&gt;http://qstardict.ylsoftware.com&lt;/a&gt;</source>
        <translation>Copyright (C) 2007 Александр Родин &lt;a href=&quot;http://qstardict.ylsoftware.com&quot;&gt;http://qstardict.ylsoftware.com&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="13"/>
        <source>QStarDict</source>
        <translation>QStarDict</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="183"/>
        <source>%1 - QStarDict</source>
        <translation>%1 - QStarDict</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="58"/>
        <source>Clear the search box</source>
        <translation>Очистить строку поиска</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="61"/>
        <source>Clear</source>
        <translation>Очистить</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="77"/>
        <source>Fuzzy query</source>
        <translation>Неточный запрос</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="80"/>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Words list</source>
        <translation>Список слов</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="147"/>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="153"/>
        <source>&amp;Help</source>
        <translation>&amp;Справка</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <source>&amp;Settings</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="174"/>
        <source>&amp;Quit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="177"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <source>&amp;About</source>
        <translation>&amp;О программе QStarDict</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="187"/>
        <source>About &amp;Qt</source>
        <translation>О &amp;библиотеке Qt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="195"/>
        <source>&amp;Configure QStarDict</source>
        <translation>&amp;Конфигурация</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>&amp;Scan</source>
        <translation>&amp;Сканировать</translation>
    </message>
</context>
<context>
    <name>QStarDict::SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="68"/>
        <source>Enabled</source>
        <translation>Включен</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="68"/>
        <source>Name</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="68"/>
        <source>Plugin</source>
        <translation>Плагин</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="261"/>
        <source>Information about dictionary &quot;%1&quot;</source>
        <translation>Информация о словаре &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="279"/>
        <source>&lt;b&gt;Name:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation>&lt;b&gt;Название:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="263"/>
        <source>&lt;b&gt;Plugin:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation>&lt;b&gt;Плагин:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="265"/>
        <source>unknown</source>
        <translation>неизвестно</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="283"/>
        <source>&lt;b&gt;Description:&lt;/b&gt; %1</source>
        <translation>&lt;b&gt;Описание:&lt;/b&gt; %1</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="278"/>
        <source>Information about %1 plugin</source>
        <translation>Информация о плагине %1</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="280"/>
        <source>&lt;b&gt;Version:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation>&lt;b&gt;Версия:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="281"/>
        <source>&lt;b&gt;Authors:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation>&lt;b&gt;Авторы:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="281"/>
        <source>&lt;br&gt;</source>
        <translation>&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="282"/>
        <source>&lt;b&gt;Can search similar words:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation>&lt;b&gt;Возможность искать похожие слова:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="282"/>
        <source>yes</source>
        <translation>есть</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="282"/>
        <source>no</source>
        <translation>нет</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>QStarDict Settings</source>
        <translation>Настройки QStarDict</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="16"/>
        <source>Show information about dictionary</source>
        <translation>Показать информацию о словаре</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Global settings</source>
        <translation>Общие настройки</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Instant search</source>
        <translation>Поиск при наборе</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="87"/>
        <source>Pronounce words using this command:</source>
        <translation>Произносить слова, используя программу:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="94"/>
        <source>Enter cmd for the speaching program.&lt;br&gt;If cmd contains &quot;%s&quot; it will be replaced to word, else word will be writen to stdin of speech process.</source>
        <translation>Введите команду для запуска программы.&lt;br&gt;Если команда содержит выражение &quot;%s&quot;, оно будет заменено на слово; иначе слово будет записано в стандартный поток ввода процесса.</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="123"/>
        <source>Dictionaries</source>
        <translation>Словари</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="147"/>
        <source>Move up</source>
        <translation>Переместить вверх</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="150"/>
        <source>Up</source>
        <translation>Вверх</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="160"/>
        <source>Move down</source>
        <translation>Переместить вниз</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="163"/>
        <source>Down</source>
        <translation>Вниз</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="173"/>
        <source>Show info</source>
        <translation>Показывать информацию</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="207"/>
        <source>Plugins</source>
        <translation>Плагины</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="234"/>
        <source>Show information about plugin</source>
        <translation>Показать информацию о плагине</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="237"/>
        <source>Info</source>
        <translation>Информация</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="247"/>
        <source>Configure plugin</source>
        <translation>Настроить плагин</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="250"/>
        <source>Configure</source>
        <translation>Настроить</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="279"/>
        <source>Popup window</source>
        <translation>Всплывающее окно</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="303"/>
        <source>Behavior</source>
        <translation>Поведение</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="344"/>
        <source>Pronounce the word</source>
        <translation>Произносить слово</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="370"/>
        <source>Timeout before hide after mouse over</source>
        <translation>Задержка перед скрытием после отведения указателя мыши</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="377"/>
        <source>Don&apos;t hide</source>
        <translation>Не скрывать</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="380"/>
        <source> sec</source>
        <translation>сек</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="424"/>
        <source>Show only if modifier pressed</source>
        <translation>Показывать только если нажата клавиша-модификатор</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="435"/>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="440"/>
        <source>Control</source>
        <translation>Control</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="445"/>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="450"/>
        <source>Win</source>
        <translation>Win</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="460"/>
        <source>Scan selection</source>
        <translation>Сканировать выделение</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="470"/>
        <source>Show if word not found</source>
        <translation>Показывать если слово не найдено</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="644"/>
        <source>Apperance</source>
        <translation>Внешний вид</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="521"/>
        <source>Opacity</source>
        <translation>Непрозрачность</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="528"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="566"/>
        <source>Default width</source>
        <translation>Ширина по умолчанию</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="605"/>
        <source>Default height</source>
        <translation>Высота по умолчанию</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="264"/>
        <source>&lt;b&gt;Author:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation>&lt;b&gt;Автор:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="265"/>
        <source>&lt;b&gt;Words count:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation>&lt;b&gt;Количество слов:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="113"/>
        <source>All translation</source>
        <translation>Весь перевод</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="114"/>
        <source>Dictionary name</source>
        <translation>Название словаря</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="115"/>
        <source>Title</source>
        <translation>Заголовок</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="116"/>
        <source>Explanation</source>
        <translation>Пояснение</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="117"/>
        <source>Abbreviation</source>
        <translation>Аббревиатура</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="118"/>
        <source>Example</source>
        <translation>Пример употребления слова</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="119"/>
        <source>Transcription</source>
        <translation>Транскрипция</translation>
    </message>
</context>
<context>
    <name>QStarDict::TrayIcon</name>
    <message>
        <location filename="../trayicon.cpp" line="36"/>
        <source>QStarDict</source>
        <translation>QStarDict</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="37"/>
        <source>&amp;Scan</source>
        <translation>&amp;Сканировать</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="47"/>
        <source>&amp;Configure QStarDict</source>
        <translation>&amp;Конфигурация</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="50"/>
        <source>&amp;Quit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="84"/>
        <source>QStarDict: scanning is %1</source>
        <translation type="unfinished">QStarDict: сканирование %1</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="84"/>
        <source>enabled</source>
        <translation type="unfinished">включено</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="84"/>
        <source>disabled</source>
        <translation type="unfinished">выключено</translation>
    </message>
</context>
</TS>
